/*************************************************************************

         name: englishLexicon.pl
      version: November 12, 1997; March 9, 1999.
  description: Lexical entries for a small coverage of English
      authors: Patrick Blackburn & Johan Bos
   new domain: Stephan Walter & Aljoscha Burchardt (July 2002)
 
This file contains the lexical entries for a small fragment of
English.  Entries have the form lexicon(Cat,Sym,Phrase,Misc), where
Cat is the syntactic category, Sym the predicate symbol introduced
by the phrase, Phrase a list of the words that form the phrase, and
Misc miscellaneous information depending on the the type of entry.

*************************************************************************/

:- module(englishLexicon,[lexicon/4]).

/*========================================================================
   Determiners: lexicon(det,_,Words,Type)
========================================================================*/

lexicon(det,_,[every],uni).
lexicon(det,_,[a],indef).
lexicon(det,_,[which],wh).

/*========================================================================
   Nouns: lexicon(noun,Symbol,Words,[])
========================================================================*/

lexicon(noun,bird,[bird],[]).
lexicon(noun,husband,[husband],[]).
lexicon(noun,man,[man],[]).
lexicon(noun,moron,[moron],[]).
lexicon(noun,owner,[owner],[]).
lexicon(noun,person,[person],[]).
lexicon(noun,siamesecat,[siamese,cat],[]).
lexicon(noun,therapist,[therapist],[]).
lexicon(noun,wife,[wife],[]).
lexicon(noun,woman,[woman],[]).


/*========================================================================
   Proper Names: lexicon(pn,Symbol,Words,[])
========================================================================*/

lexicon(pn,anna,[anna],[]).
lexicon(pn,john,[john],[]).
lexicon(pn,mary,[mary],[]).
lexicon(pn,mutz,[mutz],[]).
lexicon(pn,mutzi,[mutzi],[]).
lexicon(pn,peter,[peter],[]).
lexicon(pn,tiger,[tiger],[]).
lexicon(pn,tweety,[tweety],[]).


/*========================================================================
   Noun Phrases: lexicon(np,Symbol,Words,Type)
========================================================================*/

lexicon(np,person,[who],wh).


/*========================================================================
   Noun Phrases: lexicon(pro,Symbol,Words,[])
========================================================================*/

lexicon(pro,male,[he],[]).
lexicon(pro,female,[she],[]).
lexicon(pro,nonhuman,[it],[]).
lexicon(pro,male,[him],[]).
lexicon(pro,female,[her],[]).


/*========================================================================
   Intransitive Verbs: lexicon(iv,Symbol,Words,{fin,inf})
========================================================================*/

lexicon(iv,purr,[purrs],fin).
lexicon(iv,purr,[purr],inf).
lexicon(iv,smoke,[smokes],fin).
lexicon(iv,smoke,[smoke],inf).
lexicon(iv,talk,[talks],fin).
lexicon(iv,talk,[talk],inf).
lexicon(iv,walk,[walks],fin).
lexicon(iv,walk,[walk],inf).
lexicon(iv,work,[works],fin).
lexicon(iv,work,[work],inf).


/*========================================================================
   Transitive Verbs: lexicon(tv,Symbol,Words,{fin,inf})
========================================================================*/

lexicon(tv,eat,[eats],fin).
lexicon(tv,eat,[eat],inf).
lexicon(tv,hate,[hates],fin).
lexicon(tv,hate,[hate],inf).
lexicon(tv,kill,[kills],fin).
lexicon(tv,kill,[kill],inf).
lexicon(tv,like,[likes],fin).
lexicon(tv,like,[like],inf).
lexicon(tv,love,[loves],fin).
lexicon(tv,love,[love],inf).
lexicon(tv,smoke,[smokes],fin).
lexicon(tv,smoke,[smoke],inf).
lexicon(tv,visit,[visits],fin).
lexicon(tv,visit,[visit],inf).


/*========================================================================
   Copula
========================================================================*/

lexicon(cop,'=',[is],fin).


/*========================================================================
   Prepositions: lexicon(prep,Symbol,Words,_)
========================================================================*/

lexicon(prep,about,[about],_).
lexicon(prep,in,[in],_).
lexicon(prep,of,[of],_).
lexicon(prep,with,[with],_).


/*========================================================================
   Adjectives: lexicon(adj,Symbol,Words,_)
========================================================================*/

lexicon(adj,big,[big],_).
lexicon(adj,female,[female],_).
lexicon(adj,male,[male],_).
lexicon(adj,married,[married],_).
lexicon(adj,mortal,[mortal],_).


/*========================================================================
   Relative Pronouns: lexicon(relpro,_,Words,_)
========================================================================*/

lexicon(relpro,_,[who],_).
lexicon(relpro,_,[that],_).


/*========================================================================
   Coordinations: lexicon(coord,_,Words,{conj,disj})
========================================================================*/

lexicon(coord,_,[and],conj).
lexicon(coord,_,[or],disj).


/*========================================================================
   Modifiers: lexicon(mod,_,Words,Type)
========================================================================*/

lexicon(mod,_,[does,not],neg).
lexicon(mod,_,[did,not],neg).
